@@ -16,7 +16,7 @@ use Getopt::Long;
 use IO::File;
 use MP3::Info;
 
-my ($tnumdir, $tnumfile, $tsize, $tmin, $tsec) = 0;
+my ($tnumdir, $tnumfile, $tsize, $tmin, $tsec) = (0, 0, 0, 0, 0);
 my ($template_header, $template_itemheader, $template_itemitem, $template_itemfooter, $template_footer);
 my (@dirs, $printmode, $title, $outfile);
 
@@ -129,8 +129,8 @@ $t_numdirs = $tnumdir;
 $t_numfiles = $tnumfile;
 $t_size = sprintf("%.2f GB (%.2f MB)", $tsize/1024/1024/1024, $tsize/1024/1024);
 $t_playtime = englishtime(60 * $tmin + $tsec);
-$t_avgsize = sprintf("%.2f MB", $tsize/1024/1024/$t_numfiles);
-$t_avgplaytime = englishtime(sprintf("%.2f", (60 * $tmin + $tsec)/$t_numfiles));
+$t_avgsize = sprintf("%.2f MB", $t_numfiles ? $tsize/1024/1024/$t_numfiles : 0);
+$t_avgplaytime = englishtime(sprintf("%.2f", $t_numfiles ? (60 * $tmin + $tsec)/$t_numfiles : 0));
 
 $report_header = $template_header;
 $report_footer = $template_footer;
@@ -152,7 +152,12 @@ exit;
 
 sub dodir {
   my $dir = shift;
-  print STDERR "\nScanning $dir...";
+  if ( -r $dir ) {
+    print STDERR "\nScanning $dir...";
+  } else {
+    print STDERR "\nSkipping $dir...";
+    return
+  }
   opendir(DIR, $dir) || die("couldn't open dir $dir: $!");
   my @files = sort grep { /\.mp3$/i } readdir(DIR);
   if (@files) {
@@ -468,7 +473,7 @@ The local date and time when the report was generated.
 
 =item $t_dirs
 
-The list of parent directories that was scanned in the report. Each directory is separated by C<<BR&gt;&amp;nbsp;&amp;nbsp;> so that they are on seperate lines and indented.
+The list of parent directories that was scanned in the report. Each directory is separated by C<<BR&gt;&amp;nbsp;&amp;nbsp;> so that they are on separate lines and indented.
 
 =item $t_numdirs
 
@@ -488,7 +493,7 @@ The total playing time of all songs combined. This is formatted into an English
 
 =item $t_exectime
 
-The total time it took to genereate the report. This is formatted into an English sentence (4 days, 3 hours, 2 minutes, 1 second).
+The total time it took to generate the report. This is formatted into an English sentence (4 days, 3 hours, 2 minutes, 1 second).
 
 =item $t_avgsize
 
